API docs for “spamfighter.core.test.test_rules.RulesFactoryTestCase”

# Class s.c.t.t.RulesFactoryTestCase(unittest.TestCase):

Part of spamfighter.core.test.test_rules View Source View In Hierarchy

Тест на `spamfighter.core.rules.RulesFactory`.

Method | setUp | Undocumented
Method | testRegisterRule | Undocumented
Method | testUnRegisterRule | Undocumented
Method | testInstanciateRule | Undocumented

def setUp(self): (source)
Undocumented
def testRegisterRule(self): (source)
Undocumented
def testUnRegisterRule(self): (source)
Undocumented
def testInstanciateRule(self): (source)
Undocumented